@@ -5,14 +5,14 @@ using namespace arma;
 using namespace std;
 
 colvec GdensV(const colvec x){
-  return exp(-0.5 * x % x) / sqrt(2 * PI);
+  return exp(-0.5 * x % x) / sqrt(2 * M_PI);
 }
 
 double Gdens(const double x){
-  return exp(-0.5 * x * x) / sqrt(2 * PI);
+  return exp(-0.5 * x * x) / sqrt(2 * M_PI);
 }
 Col<double> Gdensbis(Col<double> x){
-  return exp(-0.5 * x % x) / sqrt(2 * PI);
+  return exp(-0.5 * x % x) / sqrt(2 * M_PI);
 }
 
 // [[Rcpp::export]]
